<?php
// $Id;

/**
 * @file
 * Utility functions for Solr date manipulation
 * <code>
 *   $date = xc_solr_str_to_date('1900-01-01T00:00:01Z');
 *   ... // manipulation with date_* functions
 *   $solr_date_str = xc_solr_date_to_solr($date);
 *   
 *   $ISO_date_str = xc_solr_solr_to_iso('1900-01-01T00:00:01Z'); // 1900-01-01T00:00:01+0000
 *   $solr_date_str = xc_solr_iso_to_solr('1900-01-01T00:00:01+0000'); // 1900-01-01T00:00:01Z
 *   
 *   $last_years_end = xc_solr_date_modify('1900-01-01T00:00:01Z', '-1 second');
 * </code>
 */

/**
 * Modify a Solr date string
 * @param $date_str (String)
 *   A Solr date string, like 1900-01-01T00:00:01Z
 * @param $modify (String)
 *   String in a relative format accepted by strtotime(). Examples: "now", 
 *   "+1 day", "+1 week", "+1 week 2 days 4 hours 2 seconds", "next Thursday",
 *   "last Monday"
 * @return (String)
 *   A the new Solr date string, like 1900-01-01T00:00:01Z
 */
function xc_solr_date_modify($date_str, $modify) {
  $date = xc_solr_str_to_date($date_str);
  date_modify($date, $modify);
  return xc_solr_date_to_solr($date);
}

/**
 * Transform a Solr date string to DateTime object 
 * @param $date_str (String)
 *   A Solr date string, like 1900-01-01T00:00:01Z
 * @return (DateTime)
 *   A DateTime object
 */
function xc_solr_str_to_date($date_str) {
  static $date_time_zone;
  if(is_null($date_time_zone)) {
    $date_time_zone = new DateTimeZone('GMT');
  }
  return date_create(xc_solr_solr_to_iso($date_str), $date_time_zone);
}

/**
 * Transform DateTime object to Solr date string
 * @param $date (DateTime)
 *   A DateTime object
 * @return (String)
 *   A Solr date string, like 1900-01-01T00:00:01Z
 */
function xc_solr_date_to_solr($date) {
  return xc_solr_iso_to_solr(date_format($date, DATE_ISO8601));
}

/**
 * Transform Solr date format (1900-01-01T00:00:01Z) to ISO 8601 format 
 * (1900-01-01T00:00:01+0000)
 * @param $date_str (string)
 *   Date in Solr format (1900-01-01T00:00:01Z)
 * @return (String)
 *   Date in ISO 8601 format (1900-01-01T00:00:01+0000)
 */
function xc_solr_solr_to_iso($date_str) {
  return str_replace('Z', '+0000', $date_str);
}

/**
 * Transform ISO 8601 date format (1900-01-01T00:00:01+0000) to Solr date 
 * format (1900-01-01T00:00:01Z) 
 * @param $date_str (string)
 *   Date in ISO 8601 format (1900-01-01T00:00:01+0000)
 * @return (String)
 *   Date in Solr format (1900-01-01T00:00:01Z)
 */
function xc_solr_iso_to_solr($date_str) {
  return str_replace('+0000', 'Z', $date_str);
}

